pygeodesy.props.DeprecationWarnings

Package pygeodesy :: Module props :: Class DeprecationWarnings |
[frames] | no frames]

# Class DeprecationWarnings

    object --+
             |
            DeprecationWarnings

(INTERNAL) Handle `DeprecationWaring`s.

Instance Methods
__call__(self) Have any `DeprecationWarning`s been reported or raised? |
throw(self, kind, name, doc, **stacklevel) Report or raise a `DeprecationWarning`. |
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties
| Warnings Get the number of `DeprecationWarning`s (`int`) so far or `None` if not enabled.
Inherited from `object`: `__class__`

Method Details

### __call__ (self) (Call operator) |
Have any `DeprecationWarning`s been reported or raised? Returns: The number of `DeprecationWarning`s (`int`) so far or `None` if not enabled. Note: To get `DeprecationWarning`s if any, run `python` with env var `PYGEODESY_WARNINGS` set to a non-empty string AND use `python[3]` command line option `-X dev`, `-W always` or `-W error`, etc.

### throw (self, kind, name, doc, **stacklevel) |
Report or raise a `DeprecationWarning`. Arguments: `kind` - Warning kind (`str`), `"method"`, `"funtion"`, ... `name` - Qualified name (`str`) of `kind`. `doc` - The __doc__ (`str`) of `kind`, `"DEPRECATED ...`.

Property Details

### Warnings Get the number of `DeprecationWarning`s (`int`) so far or `None` if not enabled. Get method: Warnings(self) - Get the number of `DeprecationWarning`s (`int`) so far or `None` if not enabled. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.